==> img0ch-2.1.3.tar.bz2: img0ch/_template/type/read.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript">
//<![CDATA[
jQuery(function () {
    jQuery("//input[@name='FROM']").val(jQuery.cookie("NAME"));
    jQuery("//input[@name='mail']").val(jQuery.cookie("MAIL"));
    jQuery("form.comment").submit(function () {
        if ( !jQuery("textarea[@name='MESSAGE']", this).val() &&
            jQuery("input[@type='submit']", this).val() == "" ) {
            if ( confirm("{܂Błe܂H") == false ) {
                return false;
            }
        }
        var option = { "expires": 30, "path": "<?cs var:BBS_COOKIE_PATH ?>" };
        jQuery.cookie( "NAME", jQuery( "input[@name='FROM']", this ).val(), option );
        jQuery.cookie( "MAIL", jQuery( "input[@name='mail']", this ).val(), option );
        jQuery("//input[@type='submit']").attr({ "disabled": true });
        return true;
    });
});
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
body { font-family: "Mona","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS PSVbN","MS PSVbN",sans-serif; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { line-height: 100% !important; }
/* ]]> */
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>
<body>

<h1><?cs var:Subject ?></h1>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject"><?cs var:Subject ?></span>
 </h2>

 <div class="form">
  <div class="caption">
   <a href="<?cs var:BBSURI ?>/">fɖ߂遡</a>
   <a href="<?cs var:ReadCGIURI ?>/">S</a>
   <a href="<?cs var:ReadCGIURI ?>/1-100">1-</a>
   <!--XɉăNo͂-->
   <?cs each:item = LinkStack ?>
    <a href="<?cs var:iReadCGIURI ?>/<?cs var:item.start ?>-<?cs var:item.end ?>">
     <?cs var:item.start ?>-
    </a>
   <?cs /each ?>
   <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̑傫<strong><?cs var:DatKByteSize ?></strong>KBłB<br />
  <!--Xɂď݂oȂȂ邱Ƃ\o͂-->
   <?cs if:R100 ?>
    X1000𒴂Ă܂BcOȂS͕\܂B
   <?cs elif:R95 ?>
    X950𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs elif:R90 ?>
    X900𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs /if ?> <!-- NAME=90 -->
   </p>
  </div>
 </div>

 <div class="body thread_body" id="t_<?cs var:KEY ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:res.resno ?>">
    <div class="caption res_header">
     <?cs var:res.resno ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:res.mail ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:res.date ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <?cs if:!R100 ?>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="key" value="<?cs var:key ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" value="" size="19" />
   </div>
   <div class="field mail">
    [F<input type="text" name="mail" value="" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
    <div class="textarea">摜F<input type="file" name="file" size="74" /></div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <?cs /if ?>
 <div class="referer">
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:ResCount ?>-n">VX̕\</a>
  <a href="<?cs var:BBSURI ?>/">fɖ߂</a>
  <a href="<?cs var:ReadCGIURI ?>/">S</a>
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
  <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
 </div>
</div>

<div class="footer">
 <?cs var:html_escape(VERSION ESCAPE) ?>
</div>

</body>
</html>

==> img0ch-2.1.4.tar.bz2: img0ch/_template/type/read.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:BBS_TITLE ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:StaticURI ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:BBS_TYPE_THEME ?>/<?cs var:BBS_TYPE_THEME ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/jquery/cookie.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:StaticURI ?>/js/img0ch/app.js?v=?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBSURI("<?cs var:BBSURI ?>");
app.setCGIURI("<?cs var:CGIURI ?>");
app.initForm("<?cs var:BBS_COOKIE_PATH ?>");
//]]>
</script>
<style type="text/css">
/*
<![CDATA[
<!--nobanner-->
*/
a { color: <?cs var:BBS_LINK_COLOR ?>; }
a:active { color: <?cs var:BBS_ALINK_COLOR ?>; }
a:visited { color: <?cs var:BBS_VLINK_COLOR ?>; }
body { font-family: "Mona","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS PSVbN","MS PSVbN",sans-serif; }
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.nomail { color: <?cs var:BBS_NAME_COLOR ?> }
.right { text-align: right !important; }
.thread_info {}
.res_body { line-height: 110% !important; }
/* ]]> */
</style>
<!--meta.txto͕-->
<?cs var:META ?>
</head>
<body>

<h1><?cs var:Subject ?></h1>

<!--L\-->
<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject"><?cs var:Subject ?></span>
 </h2>

 <div class="form">
  <div class="caption">
   <a href="<?cs var:BBSURI ?>/">fɖ߂遡</a>
   <a href="<?cs var:ReadCGIURI ?>/">S</a>
   <a href="<?cs var:ReadCGIURI ?>/1-100">1-</a>
   <!--XɉăNo͂-->
   <?cs each:item = LinkStack ?>
    <a href="<?cs var:iReadCGIURI ?>/<?cs var:item.start ?>-<?cs var:item.end ?>">
     <?cs var:item.start ?>-
    </a>
   <?cs /each ?>
   <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̑傫<strong><?cs var:DatKByteSize ?></strong>KBłB<br />
  <!--Xɂď݂oȂȂ邱Ƃ\o͂-->
   <?cs if:R100 ?>
    X1000𒴂Ă܂BcOȂS͕\܂B
   <?cs elif:R95 ?>
    X950𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs elif:R90 ?>
    X900𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs /if ?> <!-- NAME=90 -->
   </p>
  </div>
 </div>

 <div class="body thread_body" id="t_<?cs var:KEY ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:res.resno ?>">
    <div class="caption res_header">
     <?cs var:res.resno ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:res.mail ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:res.date ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <?cs if:!R100 ?>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:CGIURI ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:BBS ?>" />
    <input type="hidden" name="key" value="<?cs var:key ?>" />
    <input type="hidden" name="time" value="<?cs var:TimeStamp ?>" />
   </div>
   <div class="field name">
    OF<input type="text" name="FROM" value="" size="19" />
   </div>
   <div class="field mail">
    [F<input type="text" name="mail" value="" size="19" />
   </div>
   <?cs if:UploadableFromRes ?>
   <div class="field name">
    <br />摜F<input type="file" name="file" />
   </div>
   <?cs if:BBS_IMG_REQUIRE_REMOVE_KEY ?>
   <div class="field mail">
    폜pXF<input type="password" name="pass" />
   </div>
   <?cs /if ?>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <?cs /if ?>
 <div class="referer">
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:ResCount ?>-n">VX̕\</a>
  <a href="<?cs var:BBSURI ?>/">fɖ߂</a>
  <a href="<?cs var:ReadCGIURI ?>/">S</a>
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:PrevStart ?>-<?cs var:PrevEnd ?>">O100</a>
  <a href="<?cs var:ReadCGIURI ?>/<?cs var:NextStart ?>-<?cs var:NextEnd ?>">100</a>
  <a href="<?cs var:ReadCGIURI ?>/l50">ŐV50</a>
 </div>
</div>

<div class="footer">
 <?cs var:html_escape(VERSION ESCAPE) ?>
</div>

</body>
</html>
